import argparse

from nameko.cli.main import setup_yaml_parser, CommandError, ConfigurationError
from ..cli_commands import RunExtra
from . import run


def setup_parser():
    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers()
    command = RunExtra
    command_parser = subparsers.add_parser(
        command.name, description=command.__doc__)
    command.init_parser(command_parser)
    command_parser.set_defaults(main=command.main)
    return parser


def main():
    parser = setup_parser()
    args = parser.parse_args()
    setup_yaml_parser()
    try:
        run.main(args)
    except (CommandError, ConfigurationError) as exc:
        print("Error: {}".format(exc))



from nameko.cli.commands import Run


class RunExtra(Run):
    """Nameko run command with additional args"""
    name = 'run'

    @staticmethod
    def init_parser(parser):
        parser.add_argument(
            'services', nargs='+',
            metavar='module[:service class]',
            help='python path to one or more service classes to run')

        parser.add_argument(
            '--config', default='',
            help='The YAML configuration file')

        parser.add_argument(
            '--logging-config-file', default='',
            help='Path to logging configuration file')

        parser.add_argument(
            '--broker', default='pyamqp://guest:guest@localhost',
            help='RabbitMQ broker url')

        parser.add_argument(
            '--backdoor-port', type=int,
            help='Specify a port number to host a backdoor, which can be'
            ' connected to for an interactive interpreter within the running'
            ' service process using `nameko backdoor`.')
        return parser
